@@ -1,6 +1,6 @@
 /* client.c
  *
- * $Id: client.c,v 1.108 2001/03/12 22:14:43 nisse Exp $ */
+ * $Id: client.c,v 1.111 2001/03/20 17:22:23 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -26,7 +26,6 @@
 #include "abstract_io.h"
 #include "channel.h"
 #include "channel_commands.h"
-#include "client_pty.h"
 #include "connection.h"
 #include "format.h"
 #include "interact.h"
@@ -239,13 +238,15 @@ do_exit_signal(struct channel_request *c,
 
       *closure->exit_status = 7;
 
+#if 0
       signal = signal_network_to_local(signal);
 
       werror("%ups", length, msg);
-      werror("Remote process was killed by %z.%z\n",
-	     signal ? STRSIGNAL(signal) : "an unknown signal",
+#endif
+      werror("Remote process was killed by signal: %ups %z\n",
+	     length, msg,
 	     core ? "(core dumped remotely)\n": "");
-
+      
       ALIST_SET(channel->request_types, ATOM_EXIT_STATUS, NULL);
       ALIST_SET(channel->request_types, ATOM_EXIT_SIGNAL, NULL);
 
@@ -440,17 +441,6 @@ init_client_options(struct client_options *self,
   object_queue_init(&self->actions);  
 }
 
-struct client_options *
-make_client_options(struct io_backend *backend,
-		    struct exception_handler *handler,
-		    int *exit_code)
-{
-  NEW(client_options, self);
-
-  init_client_options(self, backend, handler, exit_code);
-  return self;
-}
-
 /* Host to connect to */
 DEFINE_COMMAND_SIMPLE(client_options2remote, a)
 {
