@@ -2,7 +2,7 @@
  *
  * Server specific key exchange handling
  *
- * $Id: server_keyexchange.h,v 1.10 1999/12/07 22:15:09 nisse Exp $ */
+ * $Id: server_keyexchange.h,v 1.11 2000/05/28 00:21:16 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,12 +28,14 @@
 
 #include "keyexchange.h"
 #include "publickey_crypto.h"
+#include "server_userauth.h"
 
 /* This function consumes the server key */
 struct keyexchange_algorithm *
-make_dh_server(struct diffie_hellman_method *dh);
-     /* struct alist *keys); */
+make_dh_server(struct dh_method *dh);
 
-struct install_keys *make_server_install_keys(struct object_list *algorithms);
+struct keyexchange_algorithm *
+make_srp_server(struct dh_method *dh,
+		struct user_db *db);
 
 #endif /* LSH_SERVER_KEYEXCHANGE_H_INCLUDED */
